@@ -13,7 +13,7 @@ Usage::
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
-from typing import Any, Dict, IO, List, TYPE_CHECKING, Type, Union, overload
+from typing import Any, Dict, List, TYPE_CHECKING, Type, overload
 from botocore.exceptions import ClientError as Boto3ClientError
 from mypy_boto3_appsync.paginator import (
     ListApiKeysPaginator,
@@ -148,11 +148,11 @@ class AppSyncClient:
         ],
         description: str = None,
         serviceRoleArn: str = None,
-        dynamodbConfig: DynamodbDataSourceConfigTypeDef = None,
-        lambdaConfig: LambdaDataSourceConfigTypeDef = None,
-        elasticsearchConfig: ElasticsearchDataSourceConfigTypeDef = None,
-        httpConfig: HttpDataSourceConfigTypeDef = None,
-        relationalDatabaseConfig: RelationalDatabaseDataSourceConfigTypeDef = None,
+        dynamodbConfig: "DynamodbDataSourceConfigTypeDef" = None,
+        lambdaConfig: "LambdaDataSourceConfigTypeDef" = None,
+        elasticsearchConfig: "ElasticsearchDataSourceConfigTypeDef" = None,
+        httpConfig: "HttpDataSourceConfigTypeDef" = None,
+        relationalDatabaseConfig: "RelationalDatabaseDataSourceConfigTypeDef" = None,
     ) -> CreateDataSourceResponseTypeDef:
         """
         [Client.create_data_source documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/appsync.html#AppSync.Client.create_data_source)
@@ -178,11 +178,11 @@ class AppSyncClient:
         authenticationType: Literal[
             "API_KEY", "AWS_IAM", "AMAZON_COGNITO_USER_POOLS", "OPENID_CONNECT"
         ],
-        logConfig: LogConfigTypeDef = None,
-        userPoolConfig: UserPoolConfigTypeDef = None,
-        openIDConnectConfig: OpenIDConnectConfigTypeDef = None,
+        logConfig: "LogConfigTypeDef" = None,
+        userPoolConfig: "UserPoolConfigTypeDef" = None,
+        openIDConnectConfig: "OpenIDConnectConfigTypeDef" = None,
         tags: Dict[str, str] = None,
-        additionalAuthenticationProviders: List[AdditionalAuthenticationProviderTypeDef] = None,
+        additionalAuthenticationProviders: List["AdditionalAuthenticationProviderTypeDef"] = None,
         xrayEnabled: bool = None,
     ) -> CreateGraphqlApiResponseTypeDef:
         """
@@ -198,9 +198,9 @@ class AppSyncClient:
         dataSourceName: str = None,
         responseMappingTemplate: str = None,
         kind: Literal["UNIT", "PIPELINE"] = None,
-        pipelineConfig: PipelineConfigTypeDef = None,
-        syncConfig: SyncConfigTypeDef = None,
-        cachingConfig: CachingConfigTypeDef = None,
+        pipelineConfig: "PipelineConfigTypeDef" = None,
+        syncConfig: "SyncConfigTypeDef" = None,
+        cachingConfig: "CachingConfigTypeDef" = None,
     ) -> CreateResolverResponseTypeDef:
         """
         [Client.create_resolver documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/appsync.html#AppSync.Client.create_resolver)
@@ -367,7 +367,7 @@ class AppSyncClient:
         """
 
     def start_schema_creation(
-        self, apiId: str, definition: Union[bytes, IO]
+        self, apiId: str, definition: bytes
     ) -> StartSchemaCreationResponseTypeDef:
         """
         [Client.start_schema_creation documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/appsync.html#AppSync.Client.start_schema_creation)
@@ -423,11 +423,11 @@ class AppSyncClient:
         ],
         description: str = None,
         serviceRoleArn: str = None,
-        dynamodbConfig: DynamodbDataSourceConfigTypeDef = None,
-        lambdaConfig: LambdaDataSourceConfigTypeDef = None,
-        elasticsearchConfig: ElasticsearchDataSourceConfigTypeDef = None,
-        httpConfig: HttpDataSourceConfigTypeDef = None,
-        relationalDatabaseConfig: RelationalDatabaseDataSourceConfigTypeDef = None,
+        dynamodbConfig: "DynamodbDataSourceConfigTypeDef" = None,
+        lambdaConfig: "LambdaDataSourceConfigTypeDef" = None,
+        elasticsearchConfig: "ElasticsearchDataSourceConfigTypeDef" = None,
+        httpConfig: "HttpDataSourceConfigTypeDef" = None,
+        relationalDatabaseConfig: "RelationalDatabaseDataSourceConfigTypeDef" = None,
     ) -> UpdateDataSourceResponseTypeDef:
         """
         [Client.update_data_source documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/appsync.html#AppSync.Client.update_data_source)
@@ -452,13 +452,13 @@ class AppSyncClient:
         self,
         apiId: str,
         name: str,
-        logConfig: LogConfigTypeDef = None,
+        logConfig: "LogConfigTypeDef" = None,
         authenticationType: Literal[
             "API_KEY", "AWS_IAM", "AMAZON_COGNITO_USER_POOLS", "OPENID_CONNECT"
         ] = None,
-        userPoolConfig: UserPoolConfigTypeDef = None,
-        openIDConnectConfig: OpenIDConnectConfigTypeDef = None,
-        additionalAuthenticationProviders: List[AdditionalAuthenticationProviderTypeDef] = None,
+        userPoolConfig: "UserPoolConfigTypeDef" = None,
+        openIDConnectConfig: "OpenIDConnectConfigTypeDef" = None,
+        additionalAuthenticationProviders: List["AdditionalAuthenticationProviderTypeDef"] = None,
         xrayEnabled: bool = None,
     ) -> UpdateGraphqlApiResponseTypeDef:
         """
@@ -474,9 +474,9 @@ class AppSyncClient:
         dataSourceName: str = None,
         responseMappingTemplate: str = None,
         kind: Literal["UNIT", "PIPELINE"] = None,
-        pipelineConfig: PipelineConfigTypeDef = None,
-        syncConfig: SyncConfigTypeDef = None,
-        cachingConfig: CachingConfigTypeDef = None,
+        pipelineConfig: "PipelineConfigTypeDef" = None,
+        syncConfig: "SyncConfigTypeDef" = None,
+        cachingConfig: "CachingConfigTypeDef" = None,
     ) -> UpdateResolverResponseTypeDef:
         """
         [Client.update_resolver documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/appsync.html#AppSync.Client.update_resolver)
