@@ -3,12 +3,12 @@ Main interface for appsync service type definitions.
 
 Usage::
 
-    from mypy_boto3.appsync.type_defs import CognitoUserPoolConfigTypeDef
+    from mypy_boto3.appsync.type_defs import AdditionalAuthenticationProviderTypeDef
 
-    data: CognitoUserPoolConfigTypeDef = {...}
+    data: AdditionalAuthenticationProviderTypeDef = {...}
 """
 import sys
-from typing import Dict, IO, List, Union
+from typing import Dict, List
 
 if sys.version_info >= (3, 8):
     from typing import Literal
@@ -21,37 +21,37 @@ else:
 
 
 __all__ = (
-    "CognitoUserPoolConfigTypeDef",
-    "OpenIDConnectConfigTypeDef",
     "AdditionalAuthenticationProviderTypeDef",
-    "CachingConfigTypeDef",
     "ApiCacheTypeDef",
-    "CreateApiCacheResponseTypeDef",
     "ApiKeyTypeDef",
-    "CreateApiKeyResponseTypeDef",
+    "AuthorizationConfigTypeDef",
+    "AwsIamConfigTypeDef",
+    "CachingConfigTypeDef",
+    "CognitoUserPoolConfigTypeDef",
+    "DataSourceTypeDef",
     "DeltaSyncConfigTypeDef",
     "DynamodbDataSourceConfigTypeDef",
     "ElasticsearchDataSourceConfigTypeDef",
-    "AwsIamConfigTypeDef",
-    "AuthorizationConfigTypeDef",
+    "FunctionConfigurationTypeDef",
+    "GraphqlApiTypeDef",
     "HttpDataSourceConfigTypeDef",
+    "LambdaConflictHandlerConfigTypeDef",
     "LambdaDataSourceConfigTypeDef",
+    "LogConfigTypeDef",
+    "OpenIDConnectConfigTypeDef",
+    "PipelineConfigTypeDef",
     "RdsHttpEndpointConfigTypeDef",
     "RelationalDatabaseDataSourceConfigTypeDef",
-    "DataSourceTypeDef",
-    "CreateDataSourceResponseTypeDef",
-    "FunctionConfigurationTypeDef",
-    "CreateFunctionResponseTypeDef",
-    "LogConfigTypeDef",
-    "UserPoolConfigTypeDef",
-    "GraphqlApiTypeDef",
-    "CreateGraphqlApiResponseTypeDef",
-    "PipelineConfigTypeDef",
-    "LambdaConflictHandlerConfigTypeDef",
-    "SyncConfigTypeDef",
     "ResolverTypeDef",
-    "CreateResolverResponseTypeDef",
+    "SyncConfigTypeDef",
     "TypeTypeDef",
+    "UserPoolConfigTypeDef",
+    "CreateApiCacheResponseTypeDef",
+    "CreateApiKeyResponseTypeDef",
+    "CreateDataSourceResponseTypeDef",
+    "CreateFunctionResponseTypeDef",
+    "CreateGraphqlApiResponseTypeDef",
+    "CreateResolverResponseTypeDef",
     "CreateTypeResponseTypeDef",
     "GetApiCacheResponseTypeDef",
     "GetDataSourceResponseTypeDef",
@@ -80,52 +80,18 @@ __all__ = (
     "UpdateTypeResponseTypeDef",
 )
 
-_RequiredCognitoUserPoolConfigTypeDef = TypedDict(
-    "_RequiredCognitoUserPoolConfigTypeDef", {"userPoolId": str, "awsRegion": str}
-)
-_OptionalCognitoUserPoolConfigTypeDef = TypedDict(
-    "_OptionalCognitoUserPoolConfigTypeDef", {"appIdClientRegex": str}, total=False
-)
-
-
-class CognitoUserPoolConfigTypeDef(
-    _RequiredCognitoUserPoolConfigTypeDef, _OptionalCognitoUserPoolConfigTypeDef
-):
-    pass
-
-
-_RequiredOpenIDConnectConfigTypeDef = TypedDict(
-    "_RequiredOpenIDConnectConfigTypeDef", {"issuer": str}
-)
-_OptionalOpenIDConnectConfigTypeDef = TypedDict(
-    "_OptionalOpenIDConnectConfigTypeDef",
-    {"clientId": str, "iatTTL": int, "authTTL": int},
-    total=False,
-)
-
-
-class OpenIDConnectConfigTypeDef(
-    _RequiredOpenIDConnectConfigTypeDef, _OptionalOpenIDConnectConfigTypeDef
-):
-    pass
-
-
 AdditionalAuthenticationProviderTypeDef = TypedDict(
     "AdditionalAuthenticationProviderTypeDef",
     {
         "authenticationType": Literal[
             "API_KEY", "AWS_IAM", "AMAZON_COGNITO_USER_POOLS", "OPENID_CONNECT"
         ],
-        "openIDConnectConfig": OpenIDConnectConfigTypeDef,
-        "userPoolConfig": CognitoUserPoolConfigTypeDef,
+        "openIDConnectConfig": "OpenIDConnectConfigTypeDef",
+        "userPoolConfig": "CognitoUserPoolConfigTypeDef",
     },
     total=False,
 )
 
-CachingConfigTypeDef = TypedDict(
-    "CachingConfigTypeDef", {"ttl": int, "cachingKeys": List[str]}, total=False
-)
-
 ApiCacheTypeDef = TypedDict(
     "ApiCacheTypeDef",
     {
@@ -147,53 +113,15 @@ ApiCacheTypeDef = TypedDict(
     total=False,
 )
 
-CreateApiCacheResponseTypeDef = TypedDict(
-    "CreateApiCacheResponseTypeDef", {"apiCache": ApiCacheTypeDef}, total=False
-)
-
 ApiKeyTypeDef = TypedDict(
     "ApiKeyTypeDef", {"id": str, "description": str, "expires": int}, total=False
 )
 
-CreateApiKeyResponseTypeDef = TypedDict(
-    "CreateApiKeyResponseTypeDef", {"apiKey": ApiKeyTypeDef}, total=False
-)
-
-DeltaSyncConfigTypeDef = TypedDict(
-    "DeltaSyncConfigTypeDef",
-    {"baseTableTTL": int, "deltaSyncTableName": str, "deltaSyncTableTTL": int},
-    total=False,
-)
-
-_RequiredDynamodbDataSourceConfigTypeDef = TypedDict(
-    "_RequiredDynamodbDataSourceConfigTypeDef", {"tableName": str, "awsRegion": str}
-)
-_OptionalDynamodbDataSourceConfigTypeDef = TypedDict(
-    "_OptionalDynamodbDataSourceConfigTypeDef",
-    {"useCallerCredentials": bool, "deltaSyncConfig": DeltaSyncConfigTypeDef, "versioned": bool},
-    total=False,
-)
-
-
-class DynamodbDataSourceConfigTypeDef(
-    _RequiredDynamodbDataSourceConfigTypeDef, _OptionalDynamodbDataSourceConfigTypeDef
-):
-    pass
-
-
-ElasticsearchDataSourceConfigTypeDef = TypedDict(
-    "ElasticsearchDataSourceConfigTypeDef", {"endpoint": str, "awsRegion": str}
-)
-
-AwsIamConfigTypeDef = TypedDict(
-    "AwsIamConfigTypeDef", {"signingRegion": str, "signingServiceName": str}, total=False
-)
-
 _RequiredAuthorizationConfigTypeDef = TypedDict(
     "_RequiredAuthorizationConfigTypeDef", {"authorizationType": Literal["AWS_IAM"]}
 )
 _OptionalAuthorizationConfigTypeDef = TypedDict(
-    "_OptionalAuthorizationConfigTypeDef", {"awsIamConfig": AwsIamConfigTypeDef}, total=False
+    "_OptionalAuthorizationConfigTypeDef", {"awsIamConfig": "AwsIamConfigTypeDef"}, total=False
 )
 
 
@@ -203,36 +131,27 @@ class AuthorizationConfigTypeDef(
     pass
 
 
-HttpDataSourceConfigTypeDef = TypedDict(
-    "HttpDataSourceConfigTypeDef",
-    {"endpoint": str, "authorizationConfig": AuthorizationConfigTypeDef},
-    total=False,
+AwsIamConfigTypeDef = TypedDict(
+    "AwsIamConfigTypeDef", {"signingRegion": str, "signingServiceName": str}, total=False
 )
 
-LambdaDataSourceConfigTypeDef = TypedDict(
-    "LambdaDataSourceConfigTypeDef", {"lambdaFunctionArn": str}
+CachingConfigTypeDef = TypedDict(
+    "CachingConfigTypeDef", {"ttl": int, "cachingKeys": List[str]}, total=False
 )
 
-RdsHttpEndpointConfigTypeDef = TypedDict(
-    "RdsHttpEndpointConfigTypeDef",
-    {
-        "awsRegion": str,
-        "dbClusterIdentifier": str,
-        "databaseName": str,
-        "schema": str,
-        "awsSecretStoreArn": str,
-    },
-    total=False,
+_RequiredCognitoUserPoolConfigTypeDef = TypedDict(
+    "_RequiredCognitoUserPoolConfigTypeDef", {"userPoolId": str, "awsRegion": str}
+)
+_OptionalCognitoUserPoolConfigTypeDef = TypedDict(
+    "_OptionalCognitoUserPoolConfigTypeDef", {"appIdClientRegex": str}, total=False
 )
 
-RelationalDatabaseDataSourceConfigTypeDef = TypedDict(
-    "RelationalDatabaseDataSourceConfigTypeDef",
-    {
-        "relationalDatabaseSourceType": Literal["RDS_HTTP_ENDPOINT"],
-        "rdsHttpEndpointConfig": RdsHttpEndpointConfigTypeDef,
-    },
-    total=False,
-)
+
+class CognitoUserPoolConfigTypeDef(
+    _RequiredCognitoUserPoolConfigTypeDef, _OptionalCognitoUserPoolConfigTypeDef
+):
+    pass
+
 
 DataSourceTypeDef = TypedDict(
     "DataSourceTypeDef",
@@ -249,17 +168,39 @@ DataSourceTypeDef = TypedDict(
             "RELATIONAL_DATABASE",
         ],
         "serviceRoleArn": str,
-        "dynamodbConfig": DynamodbDataSourceConfigTypeDef,
-        "lambdaConfig": LambdaDataSourceConfigTypeDef,
-        "elasticsearchConfig": ElasticsearchDataSourceConfigTypeDef,
-        "httpConfig": HttpDataSourceConfigTypeDef,
-        "relationalDatabaseConfig": RelationalDatabaseDataSourceConfigTypeDef,
+        "dynamodbConfig": "DynamodbDataSourceConfigTypeDef",
+        "lambdaConfig": "LambdaDataSourceConfigTypeDef",
+        "elasticsearchConfig": "ElasticsearchDataSourceConfigTypeDef",
+        "httpConfig": "HttpDataSourceConfigTypeDef",
+        "relationalDatabaseConfig": "RelationalDatabaseDataSourceConfigTypeDef",
     },
     total=False,
 )
 
-CreateDataSourceResponseTypeDef = TypedDict(
-    "CreateDataSourceResponseTypeDef", {"dataSource": DataSourceTypeDef}, total=False
+DeltaSyncConfigTypeDef = TypedDict(
+    "DeltaSyncConfigTypeDef",
+    {"baseTableTTL": int, "deltaSyncTableName": str, "deltaSyncTableTTL": int},
+    total=False,
+)
+
+_RequiredDynamodbDataSourceConfigTypeDef = TypedDict(
+    "_RequiredDynamodbDataSourceConfigTypeDef", {"tableName": str, "awsRegion": str}
+)
+_OptionalDynamodbDataSourceConfigTypeDef = TypedDict(
+    "_OptionalDynamodbDataSourceConfigTypeDef",
+    {"useCallerCredentials": bool, "deltaSyncConfig": "DeltaSyncConfigTypeDef", "versioned": bool},
+    total=False,
+)
+
+
+class DynamodbDataSourceConfigTypeDef(
+    _RequiredDynamodbDataSourceConfigTypeDef, _OptionalDynamodbDataSourceConfigTypeDef
+):
+    pass
+
+
+ElasticsearchDataSourceConfigTypeDef = TypedDict(
+    "ElasticsearchDataSourceConfigTypeDef", {"endpoint": str, "awsRegion": str}
 )
 
 FunctionConfigurationTypeDef = TypedDict(
@@ -277,12 +218,40 @@ FunctionConfigurationTypeDef = TypedDict(
     total=False,
 )
 
-CreateFunctionResponseTypeDef = TypedDict(
-    "CreateFunctionResponseTypeDef",
-    {"functionConfiguration": FunctionConfigurationTypeDef},
+GraphqlApiTypeDef = TypedDict(
+    "GraphqlApiTypeDef",
+    {
+        "name": str,
+        "apiId": str,
+        "authenticationType": Literal[
+            "API_KEY", "AWS_IAM", "AMAZON_COGNITO_USER_POOLS", "OPENID_CONNECT"
+        ],
+        "logConfig": "LogConfigTypeDef",
+        "userPoolConfig": "UserPoolConfigTypeDef",
+        "openIDConnectConfig": "OpenIDConnectConfigTypeDef",
+        "arn": str,
+        "uris": Dict[str, str],
+        "tags": Dict[str, str],
+        "additionalAuthenticationProviders": List["AdditionalAuthenticationProviderTypeDef"],
+        "xrayEnabled": bool,
+    },
     total=False,
 )
 
+HttpDataSourceConfigTypeDef = TypedDict(
+    "HttpDataSourceConfigTypeDef",
+    {"endpoint": str, "authorizationConfig": "AuthorizationConfigTypeDef"},
+    total=False,
+)
+
+LambdaConflictHandlerConfigTypeDef = TypedDict(
+    "LambdaConflictHandlerConfigTypeDef", {"lambdaConflictHandlerArn": str}, total=False
+)
+
+LambdaDataSourceConfigTypeDef = TypedDict(
+    "LambdaDataSourceConfigTypeDef", {"lambdaFunctionArn": str}
+)
+
 _RequiredLogConfigTypeDef = TypedDict(
     "_RequiredLogConfigTypeDef",
     {"fieldLogLevel": Literal["NONE", "ERROR", "ALL"], "cloudWatchLogsRoleArn": str},
@@ -296,55 +265,41 @@ class LogConfigTypeDef(_RequiredLogConfigTypeDef, _OptionalLogConfigTypeDef):
     pass
 
 
-_RequiredUserPoolConfigTypeDef = TypedDict(
-    "_RequiredUserPoolConfigTypeDef",
-    {"userPoolId": str, "awsRegion": str, "defaultAction": Literal["ALLOW", "DENY"]},
+_RequiredOpenIDConnectConfigTypeDef = TypedDict(
+    "_RequiredOpenIDConnectConfigTypeDef", {"issuer": str}
 )
-_OptionalUserPoolConfigTypeDef = TypedDict(
-    "_OptionalUserPoolConfigTypeDef", {"appIdClientRegex": str}, total=False
+_OptionalOpenIDConnectConfigTypeDef = TypedDict(
+    "_OptionalOpenIDConnectConfigTypeDef",
+    {"clientId": str, "iatTTL": int, "authTTL": int},
+    total=False,
 )
 
 
-class UserPoolConfigTypeDef(_RequiredUserPoolConfigTypeDef, _OptionalUserPoolConfigTypeDef):
+class OpenIDConnectConfigTypeDef(
+    _RequiredOpenIDConnectConfigTypeDef, _OptionalOpenIDConnectConfigTypeDef
+):
     pass
 
 
-GraphqlApiTypeDef = TypedDict(
-    "GraphqlApiTypeDef",
+PipelineConfigTypeDef = TypedDict("PipelineConfigTypeDef", {"functions": List[str]}, total=False)
+
+RdsHttpEndpointConfigTypeDef = TypedDict(
+    "RdsHttpEndpointConfigTypeDef",
     {
-        "name": str,
-        "apiId": str,
-        "authenticationType": Literal[
-            "API_KEY", "AWS_IAM", "AMAZON_COGNITO_USER_POOLS", "OPENID_CONNECT"
-        ],
-        "logConfig": LogConfigTypeDef,
-        "userPoolConfig": UserPoolConfigTypeDef,
-        "openIDConnectConfig": OpenIDConnectConfigTypeDef,
-        "arn": str,
-        "uris": Dict[str, str],
-        "tags": Dict[str, str],
-        "additionalAuthenticationProviders": List[AdditionalAuthenticationProviderTypeDef],
-        "xrayEnabled": bool,
+        "awsRegion": str,
+        "dbClusterIdentifier": str,
+        "databaseName": str,
+        "schema": str,
+        "awsSecretStoreArn": str,
     },
     total=False,
 )
 
-CreateGraphqlApiResponseTypeDef = TypedDict(
-    "CreateGraphqlApiResponseTypeDef", {"graphqlApi": GraphqlApiTypeDef}, total=False
-)
-
-PipelineConfigTypeDef = TypedDict("PipelineConfigTypeDef", {"functions": List[str]}, total=False)
-
-LambdaConflictHandlerConfigTypeDef = TypedDict(
-    "LambdaConflictHandlerConfigTypeDef", {"lambdaConflictHandlerArn": str}, total=False
-)
-
-SyncConfigTypeDef = TypedDict(
-    "SyncConfigTypeDef",
+RelationalDatabaseDataSourceConfigTypeDef = TypedDict(
+    "RelationalDatabaseDataSourceConfigTypeDef",
     {
-        "conflictHandler": Literal["OPTIMISTIC_CONCURRENCY", "LAMBDA", "AUTOMERGE", "NONE"],
-        "conflictDetection": Literal["VERSION", "NONE"],
-        "lambdaConflictHandlerConfig": LambdaConflictHandlerConfigTypeDef,
+        "relationalDatabaseSourceType": Literal["RDS_HTTP_ENDPOINT"],
+        "rdsHttpEndpointConfig": "RdsHttpEndpointConfigTypeDef",
     },
     total=False,
 )
@@ -359,15 +314,21 @@ ResolverTypeDef = TypedDict(
         "requestMappingTemplate": str,
         "responseMappingTemplate": str,
         "kind": Literal["UNIT", "PIPELINE"],
-        "pipelineConfig": PipelineConfigTypeDef,
-        "syncConfig": SyncConfigTypeDef,
-        "cachingConfig": CachingConfigTypeDef,
+        "pipelineConfig": "PipelineConfigTypeDef",
+        "syncConfig": "SyncConfigTypeDef",
+        "cachingConfig": "CachingConfigTypeDef",
     },
     total=False,
 )
 
-CreateResolverResponseTypeDef = TypedDict(
-    "CreateResolverResponseTypeDef", {"resolver": ResolverTypeDef}, total=False
+SyncConfigTypeDef = TypedDict(
+    "SyncConfigTypeDef",
+    {
+        "conflictHandler": Literal["OPTIMISTIC_CONCURRENCY", "LAMBDA", "AUTOMERGE", "NONE"],
+        "conflictDetection": Literal["VERSION", "NONE"],
+        "lambdaConflictHandlerConfig": "LambdaConflictHandlerConfigTypeDef",
+    },
+    total=False,
 )
 
 TypeTypeDef = TypedDict(
@@ -382,34 +343,73 @@ TypeTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredUserPoolConfigTypeDef = TypedDict(
+    "_RequiredUserPoolConfigTypeDef",
+    {"userPoolId": str, "awsRegion": str, "defaultAction": Literal["ALLOW", "DENY"]},
+)
+_OptionalUserPoolConfigTypeDef = TypedDict(
+    "_OptionalUserPoolConfigTypeDef", {"appIdClientRegex": str}, total=False
+)
+
+
+class UserPoolConfigTypeDef(_RequiredUserPoolConfigTypeDef, _OptionalUserPoolConfigTypeDef):
+    pass
+
+
+CreateApiCacheResponseTypeDef = TypedDict(
+    "CreateApiCacheResponseTypeDef", {"apiCache": "ApiCacheTypeDef"}, total=False
+)
+
+CreateApiKeyResponseTypeDef = TypedDict(
+    "CreateApiKeyResponseTypeDef", {"apiKey": "ApiKeyTypeDef"}, total=False
+)
+
+CreateDataSourceResponseTypeDef = TypedDict(
+    "CreateDataSourceResponseTypeDef", {"dataSource": "DataSourceTypeDef"}, total=False
+)
+
+CreateFunctionResponseTypeDef = TypedDict(
+    "CreateFunctionResponseTypeDef",
+    {"functionConfiguration": "FunctionConfigurationTypeDef"},
+    total=False,
+)
+
+CreateGraphqlApiResponseTypeDef = TypedDict(
+    "CreateGraphqlApiResponseTypeDef", {"graphqlApi": "GraphqlApiTypeDef"}, total=False
+)
+
+CreateResolverResponseTypeDef = TypedDict(
+    "CreateResolverResponseTypeDef", {"resolver": "ResolverTypeDef"}, total=False
+)
+
 CreateTypeResponseTypeDef = TypedDict(
-    "CreateTypeResponseTypeDef", {"type": TypeTypeDef}, total=False
+    "CreateTypeResponseTypeDef", {"type": "TypeTypeDef"}, total=False
 )
 
 GetApiCacheResponseTypeDef = TypedDict(
-    "GetApiCacheResponseTypeDef", {"apiCache": ApiCacheTypeDef}, total=False
+    "GetApiCacheResponseTypeDef", {"apiCache": "ApiCacheTypeDef"}, total=False
 )
 
 GetDataSourceResponseTypeDef = TypedDict(
-    "GetDataSourceResponseTypeDef", {"dataSource": DataSourceTypeDef}, total=False
+    "GetDataSourceResponseTypeDef", {"dataSource": "DataSourceTypeDef"}, total=False
 )
 
 GetFunctionResponseTypeDef = TypedDict(
     "GetFunctionResponseTypeDef",
-    {"functionConfiguration": FunctionConfigurationTypeDef},
+    {"functionConfiguration": "FunctionConfigurationTypeDef"},
     total=False,
 )
 
 GetGraphqlApiResponseTypeDef = TypedDict(
-    "GetGraphqlApiResponseTypeDef", {"graphqlApi": GraphqlApiTypeDef}, total=False
+    "GetGraphqlApiResponseTypeDef", {"graphqlApi": "GraphqlApiTypeDef"}, total=False
 )
 
 GetIntrospectionSchemaResponseTypeDef = TypedDict(
-    "GetIntrospectionSchemaResponseTypeDef", {"schema": Union[bytes, IO]}, total=False
+    "GetIntrospectionSchemaResponseTypeDef", {"schema": bytes}, total=False
 )
 
 GetResolverResponseTypeDef = TypedDict(
-    "GetResolverResponseTypeDef", {"resolver": ResolverTypeDef}, total=False
+    "GetResolverResponseTypeDef", {"resolver": "ResolverTypeDef"}, total=False
 )
 
 GetSchemaCreationStatusResponseTypeDef = TypedDict(
@@ -423,39 +423,39 @@ GetSchemaCreationStatusResponseTypeDef = TypedDict(
     total=False,
 )
 
-GetTypeResponseTypeDef = TypedDict("GetTypeResponseTypeDef", {"type": TypeTypeDef}, total=False)
+GetTypeResponseTypeDef = TypedDict("GetTypeResponseTypeDef", {"type": "TypeTypeDef"}, total=False)
 
 ListApiKeysResponseTypeDef = TypedDict(
-    "ListApiKeysResponseTypeDef", {"apiKeys": List[ApiKeyTypeDef], "nextToken": str}, total=False
+    "ListApiKeysResponseTypeDef", {"apiKeys": List["ApiKeyTypeDef"], "nextToken": str}, total=False
 )
 
 ListDataSourcesResponseTypeDef = TypedDict(
     "ListDataSourcesResponseTypeDef",
-    {"dataSources": List[DataSourceTypeDef], "nextToken": str},
+    {"dataSources": List["DataSourceTypeDef"], "nextToken": str},
     total=False,
 )
 
 ListFunctionsResponseTypeDef = TypedDict(
     "ListFunctionsResponseTypeDef",
-    {"functions": List[FunctionConfigurationTypeDef], "nextToken": str},
+    {"functions": List["FunctionConfigurationTypeDef"], "nextToken": str},
     total=False,
 )
 
 ListGraphqlApisResponseTypeDef = TypedDict(
     "ListGraphqlApisResponseTypeDef",
-    {"graphqlApis": List[GraphqlApiTypeDef], "nextToken": str},
+    {"graphqlApis": List["GraphqlApiTypeDef"], "nextToken": str},
     total=False,
 )
 
 ListResolversByFunctionResponseTypeDef = TypedDict(
     "ListResolversByFunctionResponseTypeDef",
-    {"resolvers": List[ResolverTypeDef], "nextToken": str},
+    {"resolvers": List["ResolverTypeDef"], "nextToken": str},
     total=False,
 )
 
 ListResolversResponseTypeDef = TypedDict(
     "ListResolversResponseTypeDef",
-    {"resolvers": List[ResolverTypeDef], "nextToken": str},
+    {"resolvers": List["ResolverTypeDef"], "nextToken": str},
     total=False,
 )
 
@@ -464,7 +464,7 @@ ListTagsForResourceResponseTypeDef = TypedDict(
 )
 
 ListTypesResponseTypeDef = TypedDict(
-    "ListTypesResponseTypeDef", {"types": List[TypeTypeDef], "nextToken": str}, total=False
+    "ListTypesResponseTypeDef", {"types": List["TypeTypeDef"], "nextToken": str}, total=False
 )
 
 PaginatorConfigTypeDef = TypedDict(
@@ -478,31 +478,31 @@ StartSchemaCreationResponseTypeDef = TypedDict(
 )
 
 UpdateApiCacheResponseTypeDef = TypedDict(
-    "UpdateApiCacheResponseTypeDef", {"apiCache": ApiCacheTypeDef}, total=False
+    "UpdateApiCacheResponseTypeDef", {"apiCache": "ApiCacheTypeDef"}, total=False
 )
 
 UpdateApiKeyResponseTypeDef = TypedDict(
-    "UpdateApiKeyResponseTypeDef", {"apiKey": ApiKeyTypeDef}, total=False
+    "UpdateApiKeyResponseTypeDef", {"apiKey": "ApiKeyTypeDef"}, total=False
 )
 
 UpdateDataSourceResponseTypeDef = TypedDict(
-    "UpdateDataSourceResponseTypeDef", {"dataSource": DataSourceTypeDef}, total=False
+    "UpdateDataSourceResponseTypeDef", {"dataSource": "DataSourceTypeDef"}, total=False
 )
 
 UpdateFunctionResponseTypeDef = TypedDict(
     "UpdateFunctionResponseTypeDef",
-    {"functionConfiguration": FunctionConfigurationTypeDef},
+    {"functionConfiguration": "FunctionConfigurationTypeDef"},
     total=False,
 )
 
 UpdateGraphqlApiResponseTypeDef = TypedDict(
-    "UpdateGraphqlApiResponseTypeDef", {"graphqlApi": GraphqlApiTypeDef}, total=False
+    "UpdateGraphqlApiResponseTypeDef", {"graphqlApi": "GraphqlApiTypeDef"}, total=False
 )
 
 UpdateResolverResponseTypeDef = TypedDict(
-    "UpdateResolverResponseTypeDef", {"resolver": ResolverTypeDef}, total=False
+    "UpdateResolverResponseTypeDef", {"resolver": "ResolverTypeDef"}, total=False
 )
 
 UpdateTypeResponseTypeDef = TypedDict(
-    "UpdateTypeResponseTypeDef", {"type": TypeTypeDef}, total=False
+    "UpdateTypeResponseTypeDef", {"type": "TypeTypeDef"}, total=False
 )
